| growth_domestic_product | R Documentation |
A dataset containing the growth domestic product for several countries from 1990 to 2016.
growth_domestic_product
A data frame with 101 rows and 28 columns:
the country in which growth domestic product was measured.
growth domestic product in 1990 for each country.
...
growth domestic product in 2016 for each country
https://www.imf.org/external/datamapper/NGDPD@WEO/OEMDC/ADVEC/WEOWORLD
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.