idld-package: Integrated Dual Local Depth

idld-packageR Documentation

Integrated Dual Local Depth

Description

The Integrated Dual Local Depth is a local depth measure for data in a Banach space based on the use of one-dimensional projections. This package contains the functions for calculations in finite dimensional spaces and the case of functional data (infinite dimensional).

Details

The DESCRIPTION file: This package was not yet installed at build time.
Index: This package was not yet installed at build time.
~~ An overview of how to use the package, including the most important functions ~~

Author(s)

Lucas Fernandez Piana, Marcela Svarc

Maintainer: Lucas Fernandez Piana <lucasfernandezpiana@gmail.com>

References

~~ Literature or other references for background information ~~

See Also

~~ Optional links to other man pages, e.g. ~~ ~~ <pkg> ~~

Examples

~~ simple examples of the most important functions ~~

lfernandezpiana/idld documentation built on Feb. 17, 2024, 11:42 p.m.