idld_cluster: IDLD Clustering

View source: R/idld_cluster.R

idld_clusterR Documentation

IDLD Clustering

Description

It is partition-based clustering technique based on local depth and distance measurement applied to data

Arguments

Z

data to apply depth. It should be an array of dimension (n,p,l) where l is the number of functional coordinates. Z[,,i] is a numeric matrix where each row represents a functional observation for i=1,...,l.

data_mf

data on which depth is based. Same format than Z.

beta

locality parameter between 0 and 1

m

number of random projections

alpha_quantile

proportions of data points to include in the deepest regions. It could be a numeric vector.

K

number of clusters

type

the data type to apply the idld, "multivariate", "functional" or "multi_functional".

verbose

if TRUE prints the algorithm progress.

Value

returns a list with the following components:

  • local_depth: A numeric vector object that contains the depth for each point.

  • region: A matrix containing, in each column, the data which is in the central region related to alpha_quantile selected.

  • clusters a matrix containing, in each column, the data partition related to alpha_quantile selected.


lfernandezpiana/idld documentation built on Feb. 17, 2024, 11:42 p.m.