idld_mf: Functional Integrated Dual Local Depth

View source: R/idid_multifuncional.R

idld_mfR Documentation

Functional Integrated Dual Local Depth

Description

Calculates the integrated dual local depth for functional data and multivariate functional data.

Arguments

Z

data to apply depth. It should be an array of dimension (n,p,l) where l is the number of functional coordinates. Z[,,i] is a numeric matrix where each row represents a functional observation for i=1,...,l.

data_mf

data on which depth is based. Same format than Z.

beta

locality parameter between 0 and 1

m

number of random projections

verbose

if TRUE prints the algorithm progress.

Value

A numeric vector object that contains the depth for each point.

Examples

data(growth_domestic_product)
data(inflation_rate)
library(abind)
m_functional_data = abind(as.matrix(growth_domestic_product[,-1]/400), 
                          as.matrix(inflation_rate[,-1]), 
                          along = 3)
local_depth = idld_mf(m_functional_data, m_functional_data, 0.3, 500, TRUE)

lfernandezpiana/idld documentation built on Feb. 17, 2024, 11:42 p.m.