| inflation_rate | R Documentation |
A dataset containing the inflation rate calculated for several countries from 1990 to 2016 based in 2016.
inflation_rate
A data frame with 101 rows and 28 columns:
the country in which the inflation rate was measured.
inflation rate in 1990 for each country.
...
inflation rate in 2016 for each country.
https://www.imf.org/external/datamapper/NGDPD@WEO/OEMDC/ADVEC/WEOWORLD
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.