| idld-package | R Documentation |
The Integrated Dual Local Depth is a local depth measure for data in a Banach space based on the use of one-dimensional projections. This package contains the functions for calculations in finite dimensional spaces and the case of functional data (infinite dimensional).
The DESCRIPTION file:
This package was not yet installed at build time.
Index: This package was not yet installed at build time.
~~ An overview of how to use the package, including the most important functions ~~
Lucas Fernandez Piana, Marcela Svarc
Maintainer: Lucas Fernandez Piana <lucasfernandezpiana@gmail.com>
~~ Literature or other references for background information ~~
~~ Optional links to other man pages, e.g. ~~
~~ <pkg> ~~
~~ simple examples of the most important functions ~~
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.