View source: R/idld_functional.R
| idld_f | R Documentation |
Calculates the integrated dual local depth for functional data and multivariate functional data.
Z |
data to apply depth. It should be a numeric matrix where each row represents an observation. |
data_f |
data on which depth is based. It should be a numeric matrix where each row represents an observation. |
beta |
locality parameter between 0 and 1 |
m |
number of random projections |
verbose |
if TRUE prints the algorithm progress. |
A numeric vector object that contains the depth for each point.
data(inflation_rate)
inflation = as.matrix(inflation_rate[,-1])
local_depth = idld_f(inflation, inflation, 0.3, 500, TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.