| idld_function | R Documentation |
Calculates the integrated dual local depth
idld(z, data, beta, m, type, verbose)
beta |
locality parameter between 0 and 1 |
m |
number of random projections |
type |
the data type to apply the idld, "multivariate", "functional" or "multi_functional". |
verbose |
if TRUE prints the algorithm progress. |
Z |
data to apply depth. It should be an array of dimension (n,p,l) where l is the number of functional coordinates. Z[,,i] is a numeric matrix where each row represents a functional observation for i=1,...,l. |
data_mf |
data on which depth is based. Same format than Z. |
A numeric vector object that contains the depth for each point.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.