View source: R/idid_multifuncional.R
| idld_mf | R Documentation |
Calculates the integrated dual local depth for functional data and multivariate functional data.
Z |
data to apply depth. It should be an array of dimension (n,p,l) where l is the number of functional coordinates. Z[,,i] is a numeric matrix where each row represents a functional observation for i=1,...,l. |
data_mf |
data on which depth is based. Same format than Z. |
beta |
locality parameter between 0 and 1 |
m |
number of random projections |
verbose |
if TRUE prints the algorithm progress. |
A numeric vector object that contains the depth for each point.
data(growth_domestic_product)
data(inflation_rate)
library(abind)
m_functional_data = abind(as.matrix(growth_domestic_product[,-1]/400),
as.matrix(inflation_rate[,-1]),
along = 3)
local_depth = idld_mf(m_functional_data, m_functional_data, 0.3, 500, TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.